@@ -9,6 +9,7 @@ from pathlib import Path
 from typing import Generator, Iterable, List, Optional, Union
 
 import numpy as np
+from PIL import Image
 from tqdm import tqdm
 
 from darwin.exceptions import NotFound
@@ -130,7 +131,7 @@ def make_class_lists(release_path: Path):
 
 
 def get_classes(
-    dataset_path: Path,
+    dataset_path: Union[Path, str],
     release_name: Optional[str] = None,
     annotation_type: str = "polygon",
     remove_background: bool = True,
@@ -155,6 +156,7 @@ def get_classes(
         List of classes in the dataset of type classes_type
     """
     assert dataset_path is not None
+    dataset_path = Path(dataset_path)
     release_path = get_release_path(dataset_path, release_name)
 
     classes_file = f"classes_{annotation_type}.txt"
@@ -555,7 +557,7 @@ def get_coco_format_record(
 def get_annotations(
     dataset_path: Union[Path, str],
     partition: Optional[str] = None,
-    split: Optional[str] = None,
+    split: Optional[str] = "default",
     split_type: Optional[str] = None,
     annotation_type: str = "polygon",
     release_name: Optional[str] = None,
@@ -571,14 +573,14 @@ def get_annotations(
     partition
         Selects one of the partitions [train, val, test]
     split
-        Selects the split that defines the percetages used (use 'split' to select the default split)
+        Selects the split that defines the percetages used (use 'default' to select the default split)
     split_type
         Heuristic used to do the split [random, stratified, None]
     annotation_type
         The type of annotation classes [tag, bounding_box, polygon]
     release_name: str
         Version of the dataset
-    annotations_format: str
+    annotation_format: str
         Re-formatting of the annotation when loaded [coco, darwin]
 
     Returns
@@ -587,8 +589,7 @@ def get_annotations(
         Dictionary containing all the annotations of the dataset
     """
     assert dataset_path is not None
-    if isinstance(dataset_path, str):
-        dataset_path = Path(dataset_path)
+    dataset_path = Path(dataset_path)
 
     release_path = get_release_path(dataset_path, release_name)
 
@@ -607,7 +608,7 @@ def get_annotations(
     # Get the list of classes
     classes = get_classes(dataset_path, release_name, annotation_type=annotation_type, remove_background=True)
     # Get the list of stems
-    if split:
+    if partition:
         # Get the split
         if split_type is None:
             split_file = f"{partition}.txt"
@@ -624,7 +625,7 @@ def get_annotations(
                 f"To split the dataset you can use 'split_dataset' from darwin.dataset.utils",
             )
     else:
-        # If the split is not specified, get all the annotations
+        # If the partition is not specified, get all the annotations
         stems = [e.stem for e in annotations_dir.glob("*.json")]
 
     images_paths = []
@@ -667,3 +668,40 @@ def get_annotations(
             with annotation_path.open() as f:
                 record = json.load(f)
             yield record
+
+
+def load_pil_image(path: Path):
+    """
+    Loads a PIL image and converts it into RGB.
+
+    Parameters
+    ----------
+    path: Path
+        Path to the image file
+
+    Returns
+    -------
+    PIL Image
+        Values between 0 and 255
+    """
+    pic = Image.open(path)
+    if pic.mode == "RGB":
+        pass
+    elif pic.mode in ("CMYK", "RGBA", "P"):
+        pic = pic.convert("RGB")
+    elif pic.mode == "I":
+        img = (np.divide(np.array(pic, np.int32), 2 ** 16 - 1) * 255).astype(np.uint8)
+        pic = Image.fromarray(np.stack((img, img, img), axis=2))
+    elif pic.mode == "I;16":
+        img = (np.divide(np.array(pic, np.int16), 2 ** 8 - 1) * 255).astype(np.uint8)
+        pic = Image.fromarray(np.stack((img, img, img), axis=2))
+    elif pic.mode == "L":
+        img = np.array(pic).astype(np.uint8)
+        pic = Image.fromarray(np.stack((img, img, img), axis=2))
+    else:
+        raise TypeError(f"unsupported image type {pic.mode}")
+    return pic
+
+
+def _is_pil_image(img):
+    return isinstance(img, Image.Image)
