@@ -4,10 +4,10 @@ from pathlib import Path
 from typing import Generator, List
 
 import numpy as np
+from upolygon import draw_polygon
 
 import darwin.datatypes as dt
 from darwin.utils import convert_polygons_to_sequences
-from upolygon import draw_polygon
 
 
 class NumpyEncoder(json.JSONEncoder):
@@ -50,6 +50,7 @@ def calculate_categories(annotation_files: List[dt.AnnotationFile]):
             if annotation_class.name not in categories and annotation_class.annotation_type in [
                 "polygon",
                 "complex_polygon",
+                "bounding_box",
             ]:
                 categories[annotation_class.name] = len(categories)
     return categories
@@ -169,6 +170,20 @@ def build_annotation(annotation_file, annotation_id, annotation: dt.Annotation,
         }
     elif annotation_type == "tag":
         pass
+    elif annotation_type == "bounding_box":
+        x = annotation.data["x"]
+        y = annotation.data["y"]
+        w = annotation.data["w"]
+        h = annotation.data["h"]
+        return build_annotation(
+            annotation_file,
+            annotation_id,
+            dt.make_polygon(
+                annotation.annotation_class.name,
+                [{"x": x, "y": y}, {"x": x + w, "y": y}, {"x": x + w, "y": y + h}, {"x": x, "y": y + h}],
+            ),
+            categories,
+        )
     else:
         print(f"skipping unsupported annotation_type '{annotation_type}'")
 
